@@ -1,6 +1,6 @@
-/* $Id: exo-toolbars-editor.c 60 2005-02-25 16:19:48Z bmeurer $ */
+/* $Id: exo-toolbars-editor.c 22088 2006-06-13 14:21:58Z benny $ */
 /*-
- * Copyright (c) 2004-2005 os-cillation e.K.
+ * Copyright (c) 2004-2006 os-cillation e.K.
  * Copyright (c) 2003      Marco Pesenti Gritti
  *
  * Written by Benedikt Meurer <benny@xfce.org>.
@@ -34,9 +34,12 @@
 
 #include <libxfce4util/libxfce4util.h>
 
+#include <exo/exo-config.h>
+#include <exo/exo-private.h>
 #include <exo/exo-string.h>
 #include <exo/exo-toolbars-editor.h>
 #include <exo/exo-toolbars-private.h>
+#include <exo/exo-alias.h>
 
 
 
@@ -97,11 +100,29 @@ static const GtkTargetEntry targets[] =
   { EXO_TOOLBARS_ITEM_TYPE, GTK_TARGET_SAME_APP, 0 },
 };
 
-static GObjectClass *parent_class;
+
+
+static GObjectClass *exo_toolbars_editor_parent_class;
 
 
 
-G_DEFINE_TYPE (ExoToolbarsEditor, exo_toolbars_editor, GTK_TYPE_VBOX);
+GType
+exo_toolbars_editor_get_type (void)
+{
+  static GType type = G_TYPE_INVALID;
+
+  if (G_UNLIKELY (type == G_TYPE_INVALID))
+    {
+      type = _exo_g_type_register_simple (GTK_TYPE_VBOX,
+                                          "ExoToolbarsEditor",
+                                          sizeof (ExoToolbarsEditorClass),
+                                          exo_toolbars_editor_class_init,
+                                          sizeof (ExoToolbarsEditor),
+                                          exo_toolbars_editor_init);
+    }
+
+  return type;
+}
 
 
 
@@ -112,7 +133,7 @@ exo_toolbars_editor_class_init (ExoToolbarsEditorClass *klass)
 
   g_type_class_add_private (klass, sizeof (ExoToolbarsEditorPrivate));
   
-  parent_class = g_type_class_peek_parent (klass);
+  exo_toolbars_editor_parent_class = g_type_class_peek_parent (klass);
 
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = exo_toolbars_editor_finalize;
@@ -134,7 +155,7 @@ exo_toolbars_editor_class_init (ExoToolbarsEditorClass *klass)
                                                         "Toolbars Model",
                                                         "Toolbars Model",
                                                         EXO_TYPE_TOOLBARS_MODEL,
-                                                        G_PARAM_READWRITE));
+                                                        EXO_PARAM_READWRITE));
 
   /**
    * ExoToolbarsEditor:ui-manager:
@@ -155,7 +176,7 @@ exo_toolbars_editor_class_init (ExoToolbarsEditorClass *klass)
                                                         "UI Manager",
                                                         "UI Manager",
                                                         GTK_TYPE_UI_MANAGER,
-                                                        G_PARAM_READWRITE));
+                                                        EXO_PARAM_READWRITE));
 }
 
 
@@ -228,7 +249,7 @@ exo_toolbars_editor_finalize (GObject *object)
   exo_toolbars_editor_set_model (editor, NULL);
   exo_toolbars_editor_set_ui_manager (editor, NULL);
 
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  (*G_OBJECT_CLASS (exo_toolbars_editor_parent_class)->finalize) (object);
 }
 
 
@@ -296,10 +317,10 @@ exo_toolbars_editor_drag_data_get (GtkWidget          *item,
   const gchar *target;
   GtkAction   *action;
 
-  action = g_object_get_data (G_OBJECT (item), "gtk-action");
+  action = g_object_get_data (G_OBJECT (item), I_("gtk-action"));
   target = (action != NULL) ? gtk_action_get_name (action) : "separator";
   gtk_selection_data_set (selection_data, selection_data->target,
-                          8, target, strlen (target));
+                          8, (const guchar *) target, strlen (target));
 }
 
 
@@ -503,7 +524,7 @@ exo_toolbars_editor_update (ExoToolbarsEditor *editor)
       image = gtk_image_new_from_stock (stock, GTK_ICON_SIZE_LARGE_TOOLBAR);
       item = exo_toolbars_editor_create_item (editor, image, text,
                                               GDK_ACTION_MOVE);
-      g_object_set_data (G_OBJECT (item), "gtk-action", action);
+      g_object_set_data (G_OBJECT (item), I_("gtk-action"), action);
       gtk_table_attach_defaults (GTK_TABLE (editor->priv->table),
                                  item, x, x + 1, y, y + 1);
 
@@ -708,3 +729,8 @@ exo_toolbars_editor_set_ui_manager (ExoToolbarsEditor *editor,
 
   exo_toolbars_editor_update (editor);
 }
+
+
+
+#define __EXO_TOOLBARS_EDITOR_C__
+#include <exo/exo-aliasdef.c>
