@@ -1,6 +1,6 @@
-/* $Id: exo.h,v 1.2 2004/09/17 09:48:24 bmeurer Exp $ */
+/* $Id: exo.h 24625 2007-01-20 13:55:48Z benny $ */
 /*-
- * Copyright (c) 2004-2005 os-cillation e.K.
+ * Copyright (c) 2004-2007 os-cillation e.K.
  *
  * Written by Benedikt Meurer <benny@xfce.org>.
  *
@@ -23,32 +23,43 @@
 #ifndef __EXO_H__
 #define __EXO_H__
 
-#ifndef EXO_API_SUBJECT_TO_CHANGE
-#error "Please define EXO_API_SUBJECT_TO_CHANGE to acknoledge your understanding that libexo hasn't reached 1.0 and is subject to API churn. See the README for a full explanation."
+/* be sure to have i18n macros available and libintl.h included! */
+#if defined(GETTEXT_PACKAGE)
+#include <glib/gi18n-lib.h>
+#else
+#include <glib/gi18n.h>
 #endif
 
-#define EXO_INSIDE_EXO_H
+#include <libxfce4util/libxfce4util.h>
 
-#include <libxfcegui4/libxfcegui4.h>
+#define EXO_INSIDE_EXO_H
 
 #include <exo/exo-config.h>
 
 #include <exo/exo-binding.h>
 #include <exo/exo-cell-renderer-ellipsized-text.h>
+#include <exo/exo-cell-renderer-icon.h>
 #include <exo/exo-ellipsized-label.h>
+#include <exo/exo-execute.h>
 #include <exo/exo-enum-types.h>
 #include <exo/exo-gdk-pixbuf-extensions.h>
 #include <exo/exo-gtk-extensions.h>
 #include <exo/exo-gobject-extensions.h>
 #include <exo/exo-icon-bar.h>
+#include <exo/exo-icon-chooser-dialog.h>
 #include <exo/exo-icon-view.h>
 #include <exo/exo-md5.h>
+#include <exo/exo-mount-point.h>
 #include <exo/exo-pango-extensions.h>
 #include <exo/exo-string.h>
 #include <exo/exo-toolbars-editor.h>
 #include <exo/exo-toolbars-editor-dialog.h>
 #include <exo/exo-toolbars-model.h>
 #include <exo/exo-toolbars-view.h>
+#include <exo/exo-tree-view.h>
+#include <exo/exo-url.h>
+#include <exo/exo-utils.h>
+#include <exo/exo-wrap-table.h>
 #include <exo/exo-xsession-client.h>
 
 #undef EXO_INSIDE_EXO_H
